# zradio

![](header.png)

## Installation

Linux:

```sh
$ python setup.py install
```

## Usage example

```sh
$ zradio
```

## Development setup

```sh
$ virtualenv venv
$ source venv/bin/activate
$ python setup.py develop
$ zradio
```

## Release History

    -   Work in progress

## Meta

André P. Santos – [@ztzandre](https://twitter.com/ztzandre) – andreztz@gmail.com

Distributed under the XYZ license. See `LICENSE` for more information.

[https://github.com/andreztz/zradio](https://github.com/andreztz/)

## Contributing

1. Fork it (<https://github.com/andreztz/zradio/fork>)
2. Create your feature branch (`git checkout -b feature/fooBar`)
3. Commit your changes (`git commit -am 'Add some fooBar'`)
4. Push to the branch (`git push origin feature/fooBar`)
5. Create a new Pull Request
